@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -106,6 +106,7 @@
 #define COMMAND_TEST_REGEX              48
 #define COMMAND_UNSET_BASE_DB           49
 #define COMMAND_COPY_CONFIG             50
+#define COMMAND_IMPORT_FILTERS          51
 
 #ifdef FANCY_CLI
 
@@ -302,6 +303,9 @@ static struct c_keywords command_keywords[] =
     { "edit-mhost-config", COMMAND_EDIT_MHOST_CONFIG },
     { "edit-mhost", COMMAND_EDIT_MHOST_CONFIG },
 
+    { "import-filters", COMMAND_IMPORT_FILTERS },
+    { "import-filter", COMMAND_IMPORT_FILTERS },
+
     { "edit-filters", COMMAND_EDIT_FILTERS },
     { "edit-filter", COMMAND_EDIT_FILTERS },
     { "new-filter", COMMAND_EDIT_FILTERS },
@@ -341,6 +345,7 @@ static struct c_keywords command_keywords[] =
 
     { "drop-config", COMMAND_DROP_CONFIG },
     { "test-regex", COMMAND_TEST_REGEX },
+    { "test-filter", COMMAND_TEST_REGEX },
 
     { "help", COMMAND_HELP },
     { "h", COMMAND_HELP },
@@ -478,7 +483,7 @@ void process_print_filters();
 void process_send_notify_test();
 void process_test_regex();
 void process_help();
-
+void process_import_filters();
 
 void print_context_error( CTL_CONTEXT *context );
 
