@@ -8,6 +8,9 @@ case ${SYSTEM} in
     AIX*)
         ARCHITECTURE="aix"
         ;;
+    Linux*)
+        ARCHITECTURE=`uname -p | tr "\ " "-"`
+        ;;
     *)
         ARCHITECTURE=`uname -p`
         ;;
@@ -48,11 +51,6 @@ fi
 
 # copy in the binaries, then strip them.
 
-if [ -f ../../cli/osiris ]; then 
-${CP} ../../cli/osiris .
-${STRIP} ./osiris
-fi
-
 ${CP} ../../osirisd/osirisd .
 ${STRIP} ./osirisd
 
@@ -74,9 +72,12 @@ Linux)
 Darwin)
     ${CP} -rf ../darwin .
     ;;
-FreeBSD|NetBSD)
+FreeBSD)
     ${CP} -rf ../freebsd .
     ;;
+NetBSD)
+    ${CP} -rf ../netbsd .
+    ;;
 SunOS*)
     ${CP} -rf ../sunos .
     ;;
