@@ -8,6 +8,9 @@ case ${SYSTEM} in
     AIX*)
         ARCHITECTURE="aix"
         ;;
+    Linux*)
+        ARCHITECTURE=`uname -p | tr "\ " "-"`
+        ;;
     *)
         ARCHITECTURE=`uname -p`
         ;;
@@ -84,9 +87,12 @@ Linux)
 Darwin)
     ${CP} -rf ../darwin .
     ;;
-FreeBSD|NetBSD)
+FreeBSD)
     ${CP} -rf ../freebsd .
     ;;
+NetBSD)
+    ${CP} -rf ../netbsd .
+    ;;
 SunOS*)
     ${CP} -rf ../sunos .
     ;;
