@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -43,6 +43,10 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#ifdef HAVE_FEATURES_H
+#include <features.h>
+#endif
+
 #ifdef WIN32
 
 #include <winsock.h>
