@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -94,6 +94,8 @@ SSL * ctl_connect( CTL_CONTEXT *context )
     osi_strlcpy( auth_context.auth_pass, context->password,
                  sizeof( auth_context.auth_pass ) );
 
+    encrypt_auth_context( &auth_context );
+
     context->ssl = NULL;
     initialize_message( &req, MESSAGE_TYPE_CONTROL_REQUEST );
 
@@ -271,6 +273,8 @@ osi_bool ctl_set_user( CTL_CONTEXT *context )
     osi_strlcpy( auth.auth_user, context->username, sizeof( auth.auth_user ) );
     osi_strlcpy( auth.auth_pass, context->password, sizeof( auth.auth_pass ) );
 
+    encrypt_auth_context( &auth );
+
     /* set command and wrap our control request. */
 
     control_request.command = CONTROL_COMMAND_SET_USER;
@@ -3817,3 +3821,52 @@ osi_bool ctl_get_database( CTL_CONTEXT *context )
     return status;
 }
 
+int sha1_buffer( char *src, int src_size, char *buffer, int buffer_size )
+{
+    int index;
+    SHA_CTX ctx;
+    unsigned char digest[SHA_DIGEST_LENGTH];
+    unsigned char file_hash[41];
+
+    if ( src == NULL || buffer == NULL || buffer_size <= 0 )
+    {
+        return -1;
+    }
+
+    SHA1_Init( &ctx );
+    SHA1_Update( &ctx, src, src_size );
+    SHA1_Final( &(digest[0]), &ctx );
+
+    for ( index = 0; index < SHA_DIGEST_LENGTH; index++ )
+    {
+        osi_snprintf( &file_hash[index * 2], 3, "%02x", digest[index] );
+    }
+
+    file_hash[40] = '\0';
+    osi_strlcpy( buffer, file_hash, buffer_size );
+
+    return 0;
+}
+
+
+void encrypt_auth_context( OSI_AUTH_CONTEXT *auth_context )
+{
+    char buf[MAX_AUTH_PASSWORD_LENGTH];
+
+    if ( auth_context == NULL )
+    {
+        return;
+    } 
+
+    if ( !auth_context->auth_pass[0] || strlen( auth_context->auth_pass) == 0 )
+    {
+        return;
+    }
+
+    sha1_buffer( auth_context->auth_pass,
+                 strlen( auth_context->auth_pass),
+                 buf, sizeof(buf) );
+
+    osi_strlcpy(auth_context->auth_pass,buf,sizeof( auth_context->auth_pass) );
+}
+
