@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -294,12 +294,13 @@ void process_directory( SCANNER *scanner, const char *directory_path )
     char path_separator[2] = { PATH_SEPARATOR, '\0' };
 
     struct stat file_stats;
+    int new_path_size;
 
 #ifndef WIN32
     int length;
     int result;
 #endif
-    
+
     block *current_block;
     osi_bool case_sensitive = TRUE;
 
@@ -372,6 +373,24 @@ void process_directory( SCANNER *scanner, const char *directory_path )
             }
             
             scanner->stats.files_encountered++;
+
+            /* first, check to see if path exceeds max. if so, we */
+            /* bail to prevent corrupted results, and possibly an */
+            /* infinite loop.                                     */
+
+            new_path_size = ( strlen( directory_path ) + 
+                              strlen( directory.filename ) + 1 );
+
+            if ( new_path_size > sizeof( file_path ) )
+            {
+                send_scan_error( OSI_ERROR_DIRECTORY_TOO_DEEP,
+                                 "directory path too deep!! \"%s\"",
+                                  directory_path );
+
+                scanner->stats.files_unreadable++;
+                continue;
+            }
+
     
             /* create the full path to the file. */
     
@@ -383,10 +402,10 @@ void process_directory( SCANNER *scanner, const char *directory_path )
             {
                 osi_strlcat( file_path, directory_path, sizeof( file_path ) );
             }
-    
+
             osi_strlcat( file_path, path_separator, sizeof( file_path ) );
             osi_strlcat( file_path, directory.filename, sizeof( file_path ) );
-    
+
             /* windows doesn't have lstat, too bad for windows. */
             
 #ifdef WIN32
@@ -686,21 +705,37 @@ exit_gracefully:
 ******************************************************************************/
 
 #if defined(SYSTEM_DARWIN)
+
+#include <sys/utsname.h>
+
 void process_file_rfork( SCANNER *scanner, SCAN_RECORD *scan_record, FILE *f )
 {
     SCAN_RECORD_UNIX_1 *r = (SCAN_RECORD_UNIX_1 *)scan_record;
     struct stat file_stats;
-    
+    struct utsname name;
+
+    char *resource_name = "/..namedfork/rsrc";
+
     if( ( scanner == NULL || scan_record == NULL ) )
     {
         return;
     }
 
+    /* older versions of Mac OS X used /rsrc for resource forks. */
+
+    if ( uname( &name ) >= 0 )
+    {
+        if ( name.release[0] < '8' )
+        {
+            resource_name = "/rsrc";
+        }
+    }
+
     /* first, stat the resource fork of the given file */
     /* the file size must be greater than zero, or we  */
     /* don't care.                                     */
 
-    osi_strlcat( r->path, "/rsrc", sizeof( r->path ) );
+    osi_strlcat( r->path, resource_name, sizeof( r->path ) );
 
     if( stat( r->path, &file_stats ) != 0 )
     {
