@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -46,6 +46,7 @@
 
 extern osi_bool run_as_daemon;
 extern int log_pipe[2];
+extern int quiet_mode;
 
 #ifdef WIN32
 extern HANDLE event_source;
@@ -66,7 +67,10 @@ void log_error( int id, const char *host, const char *message, ... )
     char buffer[MAX_LOG_MESSAGE_LENGTH] = "";
     char header[MAX_LOG_MESSAGE_LENGTH] = "";
 
-    /* setup defaults. */
+    if ( quiet_mode )
+    {
+        return;
+    }
 
     if( host != NULL )
     {
@@ -86,6 +90,10 @@ void log_error( int id, const char *host, const char *message, ... )
         va_end( ap );
     }
 
+    /* now piece the entire thing together and write to the system log. */
+
+    osi_strlcat( header, buffer, sizeof( header ) );
+
     /* apply filters. */
 
     if ( log_payload_is_filtered( buffer ) )
@@ -93,10 +101,6 @@ void log_error( int id, const char *host, const char *message, ... )
         return;
     }
 
-    /* now piece the entire thing together and write to the system log. */
-
-    osi_strlcat( header, buffer, sizeof( header ) );
-
 #ifdef WIN32
         lpszStrings[0] = header;
 
@@ -143,7 +147,10 @@ void log_info( int id, const char *host, const char *message, ... )
     char buffer[MAX_LOG_MESSAGE_LENGTH] = "";
     char header[MAX_LOG_MESSAGE_LENGTH] = "";
 
-    /* setup defaults. */
+    if ( quiet_mode )
+    {
+        return;
+    }
 
     if( host != NULL )
     {
@@ -163,17 +170,17 @@ void log_info( int id, const char *host, const char *message, ... )
         va_end( ap );
     }
 
+    /* now piece the entire thing together and write to the system log. */
+
+    osi_strlcat( header, buffer, sizeof( header ) );
+
     /* apply filters. */
-    
+
     if ( log_payload_is_filtered( buffer ) )
     {
         return;
     }
 
-    /* now piece the entire thing together and write to the system log. */
-
-    osi_strlcat( header, buffer, sizeof( header ) );
-
 #ifdef WIN32
         lpszStrings[0] = header;
 
@@ -220,7 +227,10 @@ void log_warning( int id, const char *host, const char *message, ... )
     char buffer[MAX_LOG_MESSAGE_LENGTH] = "";
     char header[MAX_LOG_MESSAGE_LENGTH] = "";
 
-    /* setup defaults. */
+    if ( quiet_mode )
+    {
+        return;
+    }
 
     if( host != NULL )
     {
@@ -240,17 +250,17 @@ void log_warning( int id, const char *host, const char *message, ... )
         va_end( ap );
     }
 
+    /* now piece the entire thing together and write to the system log. */
+
+    osi_strlcat( header, buffer, sizeof( header ) );
+
     /* apply filters. */
-    
+
     if ( log_payload_is_filtered( buffer ) )
     {
         return;
     }
 
-    /* now piece the entire thing together and write to the system log. */
-
-    osi_strlcat( header, buffer, sizeof( header ) );
-
 #ifdef WIN32
         lpszStrings[0] = header;
 
