@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -48,12 +48,14 @@ extern char root_path[MAX_PATH_LENGTH];
 extern char auth_db_path[MAX_PATH_LENGTH];
 
 extern int user_pipe[2];
+void md_auth_upgrade_legacy_entries();
 
 static osi_list auths = NULL;
 char current_user[MAX_AUTH_USERNAME_LENGTH] = "unknown";
 
 void md_auth_load_database()
 {
+    md_auth_upgrade_legacy_entries();
     md_auth_read();
 }
 
@@ -417,3 +419,59 @@ osi_list md_auth_get_list()
     return auths;
 }
 
+void md_auth_upgrade_legacy_entries()
+{
+    int result;
+    int result_size;
+
+    OSI_DB db;
+    OSI_AUTH_CONTEXT temp_auth;
+    OSI_AUTH_CONTEXT new_auth;
+
+    memset( &db, 0, sizeof( db ) );
+    osi_strlcpy( db.path, auth_db_path, sizeof( db.path ) );
+
+    if( osi_db_open( &db, OSI_DB_WRITE ) != OSI_DB_OK )
+    {
+        return;
+    }
+
+    result = osi_db_get_first_record( &db, &temp_auth, sizeof( temp_auth ),
+                                      &result_size );
+
+    if( result != OSI_DB_OK )
+    {
+        osi_db_close( &db );
+        return;
+    }
+
+    while( result == OSI_DB_OK )
+    {
+        memset( &new_auth, 0, sizeof( OSI_AUTH_CONTEXT ) );
+
+        osi_strlcpy( new_auth.auth_user, temp_auth.auth_user,
+                     sizeof( new_auth.auth_user ) );
+
+        osi_strlcpy( new_auth.auth_pass, temp_auth.auth_pass,
+                     sizeof( new_auth.auth_pass ) );
+
+        /* look for non-encrypted passwords. */
+
+        if( strlen( new_auth.auth_pass ) > 0 && 
+            strlen( new_auth.auth_pass ) != sizeof(new_auth.auth_pass)-1 )
+        {
+            log_warning( LOG_ID_AUTH_WARNING, NULL,
+                         "found cleartext password for user (%s), encrypting.",
+                         new_auth.auth_user );
+
+            encrypt_auth_context( &new_auth );
+            md_auth_set_entry( new_auth.auth_user, new_auth.auth_pass );
+        }
+
+        result = osi_db_get_next_record( &db, &temp_auth, sizeof( temp_auth ),
+                                         &result_size );
+    }
+
+    osi_db_close( &db );
+}
+
