@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -370,6 +370,7 @@ osi_bool http_request_is_authorized( const char *http_message )
 
     char password[MAX_HTTP_AUTH_PASSWORD_LENGTH];
     char decoded[MAX_HTTP_AUTH_PASSWORD_LENGTH];
+    char buf[MAX_AUTH_PASSWORD_LENGTH];
 
     OSI_AUTH_CONTEXT auth_context;
 
@@ -420,6 +421,10 @@ osi_bool http_request_is_authorized( const char *http_message )
         return FALSE;
     }
 
+    /* now encrypt/hash the pass */
+
+    sha1_buffer( pass, strlen( pass), buf, sizeof(buf) );
+
     /* now authenticate against our user database. */
 
     osi_strlcpy( auth_context.auth_user, user,
@@ -427,7 +432,7 @@ osi_bool http_request_is_authorized( const char *http_message )
 
     if( pass != NULL )
     {
-        osi_strlcpy( auth_context.auth_pass, pass,
+        osi_strlcpy( auth_context.auth_pass, buf,
                      sizeof( auth_context.auth_pass ) );
     }
 
