@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -86,7 +86,7 @@ extern OSI_MANAGEMENT_CONFIG *config;
 #define OSIRIS_SMTP_CMD_QUIT    "QUIT\r\n"
 
 #define OSIRIS_SMTP_CMD_BUFSZ   2048
-#define MAX_SMTP_LINE   128
+#define MAX_SMTP_LINE       512
 #define LOGFILE_PERMISSIONS 0600
 
 #define NOTIFY_SCHEDULE_FAIL_FORMAT  "The scheduler was unable to initiate the following scan:\r\n\r\nhost: %s\r\nscheduled scan time: %s\r\n\r\nThe scheduler produced the following error message:\r\n\r\n%s"
@@ -336,11 +336,11 @@ char * get_current_date_header()
 
 #ifdef WIN32
     get_tz_bias( tz, sizeof(tz) );
-    strftime( buf, sizeof(buf) ,"%a, %e %b %Y %H:%M:%S", loc );
+    strftime( buf, sizeof(buf) ,"%a, %d %b %Y %H:%M:%S", loc );
     osi_strlcat( buf, " ", sizeof(buf) );
     osi_strlcat( buf, tz, sizeof(buf) );
 #else
-    strftime( buf, sizeof(buf) ,"%a, %e %b %Y %H:%M:%S %z", loc );
+    strftime( buf, sizeof(buf) ,"%a, %d %b %Y %H:%M:%S %z", loc );
 #endif
     buf[39] = '\0';
 
