@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -170,22 +170,6 @@ void md_schedules_check( osi_list schedules )
             {
                 osi_uint16 type;
 
-                /* if we push base db's config, then scan this host. */
-
-                result = osi_host_push_base_db_config( s->host );
-
-                if( result != OSI_OK )
-                {
-                    schedule_failed = TRUE;
-                    failure_message = osi_get_name_for_error( result );
-
-                    log_error( LOG_ID_SCHEDULER_FAIL, s->host,
-                               "scheduler failed to push config, error: %s ",
-                               failure_message );
-
-                    goto exit_gracefully;
-                }
-
                 scan_host( s->host, &res );
                 type = GET_MESSAGE_TYPE( ((MESSAGE *)&res) );
 
