@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -72,6 +72,8 @@
 char pid_file[MAX_PATH_LENGTH] = "";
 #endif
 
+int quiet_mode = 0;
+
 static void genrsa_cb( int p, int n, void *arg );
 extern osi_bool name_regex( const char *name, const char *pattern );
 
@@ -87,9 +89,10 @@ extern osi_bool name_regex( const char *name, const char *pattern );
 int main( int argument_count, char *argument_list[] )
 {
     startup_winsock();
-
-    initialize_pipes();
+    init_windows();
+    
     initialize_root_path();
+    initialize_pipes();
     
     parse_arguments( argument_count, argument_list );
     parse_configuration_file();
@@ -197,11 +200,11 @@ void parse_configuration_file()
         if( osi_create_file( config_file_path,
             MANAGEMENT_CONFIG_FILE_PERMISSIONS ) != OSI_FILE_OK )
         {
-            osi_print_stderr( "%s: creating configuration file: %s.",
+            osi_print_stderr( "%s: unable to create configuration file: %s.",
                               PROGRAM_NAME, config_file_path );
 
             log_error( LOG_ID_DAEMON_ERROR, NULL,
-                       "creating configuration file: %s.",
+                       "unable to create configuration file: %s.",
                        config_file_path );
 
             halt( EXIT_CODE_ERROR );
@@ -346,41 +349,8 @@ void process()
 
 void initialize_root_path()
 {
-    char path[MAX_PATH_LENGTH];
     char path_separator[2] = { PATH_SEPARATOR, '\0' };    
 
-    if ( osi_osirismd_home_directory_exists() == FALSE )
-    {
-        log_error( LOG_ID_DAEMON_ERROR, NULL,"finding osiris root directory." );
-        osi_print_stderr( "error: unable to find osiris root directory." );
-
-        osi_print_stderr( "" );
-        osi_print_stderr(
-                "The osiris root directory where all host information is" );
-        osi_print_stderr(
-                "stored does not exist.  This directory must be created " );
-        osi_print_stderr(
-                "manually, e.g. /usr/local/osiris or c:\\WINNT\\osiris and" );
-        osi_print_stderr(
-                "must be owned by the same user (not root!) that this daemon" );
-        osi_print_stderr(
-                "is run as.  This root directory should not have world read" ); 
-        osi_print_stderr(
-                "or write permissions." );
-        osi_print_stderr( "" );
-
-        halt( -1 );
-    }
-
-    /* we  the root directory, save it, we will either use      */
-    /* it to setup our other paths, or it will be overwritten   */
-    /* by a command line argument.                              */
-    
-    if( osi_get_osirismd_home_directory( path, sizeof( path ) ) )
-    {
-        osi_strlcpy( root_path, path, sizeof( root_path ) );
-    }
-
     /* setup our conf file path here. */
 
     osi_strlcpy( config_file_path, root_path, sizeof( config_file_path ) );
@@ -440,13 +410,29 @@ void verify_root_directory()
     
     if( osi_directory_exists( root_path ) == FALSE )
     {
+        log_error( LOG_ID_DAEMON_ERROR, NULL,"finding osiris root directory." );
+        osi_print_stderr( "error: unable to find osiris root directory." );
+
+        osi_print_stderr( "" );
         osi_print_stderr(
-        "unable to locate root directory (%s)\ncreate if necessary.",
-        root_path );
+                "The osiris root directory where all host information is" );
+        osi_print_stderr(
+                "stored does not exist.  This directory must be created " );
+        osi_print_stderr(
+                "manually, e.g. /usr/local/osiris or c:\\WINNT\\osiris and" );
+        osi_print_stderr(
+                "must be owned by the same user (not root!) that this daemon" );
+        osi_print_stderr(
+                "is run as.  This root directory should not have world read" ); 
+        osi_print_stderr(
+                "or write permissions." );
+        osi_print_stderr( "" );
 
         halt( EXIT_CODE_ERROR );
     }
 
+    log_info( LOG_ID_DAEMON_INFO, NULL, "using root dir (%s)\n", root_path );
+
     /* now setup our paths to our cert and private keys, if they exist. */
 
     osi_strlcpy( cert_path, root_path, sizeof( cert_path ) );
@@ -680,7 +666,6 @@ void verify_host_directories()
 void parse_arguments( int argument_count, char *argument_list[] )
 {
     int count;
-    char path_separator[2] = { PATH_SEPARATOR, '\0' };
 
     for( count = 1; count < argument_count; count++ )
     {
@@ -700,14 +685,7 @@ void parse_arguments( int argument_count, char *argument_list[] )
                 osi_strlcpy( root_path, argument_list[count],
                              sizeof( root_path ) );
 
-                osi_strlcpy( config_file_path, root_path,
-                             sizeof( config_file_path ) );
-
-                osi_strlcat( config_file_path, path_separator,
-                             sizeof( config_file_path ) );
-
-                osi_strlcat( config_file_path, MANAGEMENT_CONFIG_FILE_NAME,
-                             sizeof( config_file_path ) );
+                initialize_root_path();
             }
 
             else
@@ -744,6 +722,7 @@ void parse_arguments( int argument_count, char *argument_list[] )
             }
         }
 
+#ifndef WIN32
         else if ( ( strcmp( argument_list[count], "-e" ) == 0 ||
                     strcmp( argument_list[count], "--pid" ) == 0 ) &&
                  ( count < ( argument_count - 1 ) ) )
@@ -751,6 +730,7 @@ void parse_arguments( int argument_count, char *argument_list[] )
             count++;
             osi_strlcpy( pid_file, argument_list[count], sizeof(pid_file) );
         }
+#endif
 
         else if( strcmp( argument_list[count], "--help" ) == 0 ||
                  strcmp( argument_list[count], "-h" ) == 0 )
@@ -781,6 +761,11 @@ void parse_arguments( int argument_count, char *argument_list[] )
         }
 #endif
 
+        else if ( strcmp( argument_list[count], "-q" ) == 0 )
+        {
+            quiet_mode = 1;
+        }
+
         else
         {
             print_usage();
@@ -893,6 +878,8 @@ void print_usage()
     osi_print_stdout( "  -d              : run this application as a normal daemon, not a service." );
 #endif
 
+    osi_print_stdout( "  -q              : no log messages to system log." );
+
    	osi_print_stdout( "" );
 }
 
@@ -1411,7 +1398,7 @@ void process_new_http_client( int client_socket )
     }
 
     log_info( LOG_ID_HTTP_RECEIVE, NULL, "received http request." );
-    process_http_message( client_ssl, message.data );
+    process_http_message( client_ssl, (const char *)message.data );
 
 exit_gracefully:
 
@@ -1710,7 +1697,9 @@ void handle_sigkill( int signal )
 
 void check_for_signals()
 {
+#ifndef WIN32
     int exiting = ( received_sigint | received_sigterm | received_sigkill );
+#endif
 
     if( received_sigint )
     {
@@ -1867,6 +1856,22 @@ void setup_pidfile()
 }
 
 
+/******************************************************************************
+**
+**    Function: init_windows
+**
+**    Purpose:  for windows only, initialize misc.
+**
+******************************************************************************/
+
+void init_windows()
+{
+#ifdef WIN32
+    osi_get_osirismd_home_directory( root_path, sizeof( root_path ) );
+#endif
+}
+
+
 /******************************************************************************
 **
 **    Function: startup_winsock
@@ -1982,13 +1987,16 @@ osi_bool make_certificate( X509 **x509p, EVP_PKEY **pkeyp, int bits,
 
     /* setup default values for cert fields. */
 
-    X509_NAME_add_entry_by_txt( name,"C", MBSTRING_ASC, DEFAULT_CERT_C,
+    X509_NAME_add_entry_by_txt( name, "C", MBSTRING_ASC, 
+                                (unsigned char *)DEFAULT_CERT_C,
                                 -1, -1, 0 );
 
-    X509_NAME_add_entry_by_txt( name,"CN", MBSTRING_ASC, DEFAULT_CERT_CN,
+    X509_NAME_add_entry_by_txt( name,"CN", MBSTRING_ASC, 
+                                (unsigned char *)DEFAULT_CERT_CN,
                                 -1, -1, 0 );
 
-    X509_NAME_add_entry_by_txt( name,"OU", MBSTRING_ASC, DEFAULT_CERT_OU,
+    X509_NAME_add_entry_by_txt( name,"OU", MBSTRING_ASC, 
+                                (unsigned char *)DEFAULT_CERT_OU,
                                 -1, -1, 0 );
 
     /* self signed, so we set issuer to be the same as the subject. */
