@@ -31,8 +31,10 @@
 
 char db_path[MAX_PATH_LENGTH] = "";
 
-osi_bool print_all_records = FALSE;
-osi_bool print_all_errors  = FALSE;
+osi_bool print_header = FALSE;
+osi_bool print_errors  = FALSE;
+osi_bool print_modules = FALSE;
+osi_bool print_files = FALSE;
 
 /******************************************************************************
 **
@@ -44,8 +46,14 @@ osi_bool print_all_errors  = FALSE;
 
 void print_usage()
 {
-    fprintf( stderr, "osiris db command line utility (v0.1).\n" );
-    fprintf( stdout, "usage: printdb [-a] [-e] <database>\n\n" );
+    fprintf( stderr, "osiris db command line utility (v0.2).\n" );
+    fprintf( stdout, "usage: printdb [-h] [-e] [-m] [-a] <database>\n\n" );
+    fprintf( stdout, " -h   : print database header.\n" );
+    fprintf( stdout, " -e   : print scan errors.\n" );
+    fprintf( stdout, " -m   : print module records.\n" );
+    fprintf( stdout, " -f   : print file records.\n" );
+    fprintf( stdout, " -a   : print everything.\n" ); 
+    fprintf( stdout, "\n" );
 }
 
 /******************************************************************************
@@ -70,6 +78,7 @@ void parse_arguments( int argument_count, char *argument_list[] )
     
     if( argument_count == 2 )
     {
+        print_header = TRUE;
         osi_strlcpy( db_path, argument_list[1], sizeof( db_path ) );
         return;
     }
@@ -78,17 +87,41 @@ void parse_arguments( int argument_count, char *argument_list[] )
     
     for( count = 1; count < ( argument_count - 1 ); count++ )
     {
+        if( ( strcmp( argument_list[count], "-h" ) == 0 ||
+              strcmp( argument_list[count], "--print-header" ) == 0 ) )
+        {
+            print_header = TRUE;
+            continue;
+        }
+
         if( ( strcmp( argument_list[count], "-e" ) == 0 ||
               strcmp( argument_list[count], "--print-errors" ) == 0 ) )
         {
-            print_all_errors = TRUE;
+            print_errors = TRUE;
+            continue;
+        }
+
+        if( ( strcmp( argument_list[count], "-m" ) == 0 ||
+              strcmp( argument_list[count], "--print-modules" ) == 0 ) )
+        {
+            print_modules = TRUE;
+            continue;
+        }
+
+        if( ( strcmp( argument_list[count], "-f" ) == 0 ||
+              strcmp( argument_list[count], "--print-files" ) == 0 ) )
+        {
+            print_files = TRUE;
             continue;
         }
         
         if( ( strcmp( argument_list[count], "-a" ) == 0 ||
               strcmp( argument_list[count], "--all-records" ) == 0 ) )
         {
-            print_all_records = TRUE;
+            print_header = TRUE;
+            print_files = TRUE;
+            print_modules = TRUE;
+            print_errors = TRUE;
             continue;
         }
                     
@@ -123,25 +156,30 @@ void print_database_records( OSI_DB *db )
     }
     
     record = osi_malloc( record_size );
-    result = osi_scan_db_get_first_record( db, record, record_size );
-    
-    while( result == OSI_DB_OK )
+
+    if ( print_files )
     {
-        print_scan_record( record );
-        result = osi_scan_db_get_next_record( db, record, record_size );
+        result = osi_scan_db_get_first_record( db, record, record_size );
+    
+        while( result == OSI_DB_OK )
+        {
+            print_scan_record( record );
+            result = osi_scan_db_get_next_record( db, record, record_size );
+        }
     }
 
-    /* print system records. */
-
-    fprintf( stdout, "\n[ MODULES ]\n\n" );
-    result = osi_scan_db_get_first_system( db, record, record_size );
-    
-    while( result == OSI_DB_OK )
+    if ( print_modules )
     {
-        print_scan_record( record );
-        result = osi_scan_db_get_next_system( db, record, record_size );
-    }
+        fprintf( stdout, "\n[ MODULES ]\n\n" );
+        result = osi_scan_db_get_first_system( db, record, record_size );
     
+        while( result == OSI_DB_OK )
+        {
+            print_scan_record( record );
+            result = osi_scan_db_get_next_system( db, record, record_size );
+        }
+    }
+ 
     osi_free( record );
     fprintf( stdout, "\n" );
 }
@@ -172,16 +210,19 @@ int main( int argument_count, char *argument_list[] )
         exit(-1);
     }
 
-    print_database_header( &db );
+    if ( print_header )
+    {
+        print_database_header( &db );
+    }
     
     /* now walk through the database. */
-    
-    if( print_all_records )
+
+    if ( print_modules || print_files )
     {
         print_database_records( &db );
     }
     
-    if( print_all_records || print_all_errors )
+    if( print_errors )
     {
         print_database_errors( &db );
     }
